==> exit-options_24.10.01.tar.xz: BUILD/translations/exit-options_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="24"/>
        <source>Restart Fluxbox</source>
        <translation>Fluxbox を再起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Lock Screen</source>
        <translation>画面をロック</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Log Out</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="30"/>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="32"/>
        <source>Shutdown</source>
        <translation>シャットダウン</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>MX Fluxbox の終了ポップアップ表示オプション</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation>垂直方向のウインドウにボタンを表示する</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation>水平方向のウインドウにボタンを表示する</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation>タイムアウトまでの秒数</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>ボタンを縦方向に表示するには -v, --vertical を指定します。
ボタンを水平方向に表示するには -h, --horizontal を指定します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation>使い方: exit-options [オプション]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 水平方向にボタンを表示するオプション</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 垂直方向にボタンを表示するオプション</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 タイムアウトまでの秒数
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>一度設定したディスプレイの向きは保存され、次回起動時にも使用します</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>次のように設定しても同じです。 &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>exit-options.conf によるタイムアウト設定では「timeout=X」を使用します。X はタイムアウトの秒数です。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>カスタムアイコンを定義するには exit-options.conf ファイルに IconName=/path/iconame.ext というように記述します。再マッピングするアイコン名: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>exit-options.conf ファイルで設定可能なその他のオプション: %1</translation>
    </message>
</context>
</TS>

==> exit-options_25.1.tar.xz: BUILD/translations/exit-options_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="26"/>
        <source>Restart Fluxbox</source>
        <translation>Fluxbox を再起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="28"/>
        <source>Restart IceWM</source>
        <translation>Restart を再起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="36"/>
        <source>Lock Screen</source>
        <translation>画面をロック</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="34"/>
        <source>Log Out</source>
        <translation>ログアウト</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="42"/>
        <source>Suspend</source>
        <translation>サスペンド</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="38"/>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>シャットダウン</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <location filename="../main.cpp" line="56"/>
        <source>Pop-up with exit options for MX Fluxbox</source>
        <translation>MX Fluxbox の終了ポップアップ表示オプション</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>Display buttons in a vertical window</source>
        <translation>垂直方向のウインドウにボタンを表示する</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="50"/>
        <source>Display buttons in a horizontal window</source>
        <translation>水平方向のウインドウにボタンを表示する</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Timeout duration in seconds</source>
        <translation>タイムアウトまでの秒数</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="52"/>
        <source>use -v, --vertical to display buttons vertically
use -h, --horizontal to display buttons horizontally.</source>
        <translation>ボタンを縦方向に表示するには -v, --vertical を指定します。
ボタンを水平方向に表示するには -h, --horizontal を指定します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Usage: exit-options [options]
</source>
        <translation>使い方: exit-options [オプション]
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Options:</source>
        <translation>オプション:</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>  -h, --horizontal	 Option to display buttons horizontally</source>
        <translation>  -h, --horizontal	 水平方向にボタンを表示するオプション</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="60"/>
        <source>  -v, --vertical	 Option to display buttons vertically</source>
        <translation>  -v, --vertical	 垂直方向にボタンを表示するオプション</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>  -t, --timeout &lt;sec&gt;	 Timeout duration in seconds
</source>
        <translation>  -t, --timeout &lt;sec&gt;	 タイムアウトまでの秒数
</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="62"/>
        <source>The display orientation option used will be remembered and used the next time you start the app</source>
        <translation>一度設定したディスプレイの向きは保存され、次回起動時にも使用します</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Alternativelly, set the option &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</source>
        <translation>次のように設定しても同じです。 &apos;layout=horizontal&apos; or &apos;layout=vertical&apos; in ~/.config/MX-Linux/exit-options.conf</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>To set the timeout in exit-options.conf use &apos;timeout=X&apos; where X is the timeout in seconds.</source>
        <translation>exit-options.conf によるタイムアウト設定では「timeout=X」を使用します。X はタイムアウトの秒数です。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="69"/>
        <source>You can also use &apos;timeout=off&apos; to turn the timeout off.</source>
        <translation>&apos;timeout=off&apos; を使ってもタイムアウトをオフにできます。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="71"/>
        <source>You can define custom icons by adding IconName=/path/iconame.ext in the exit-options.conf file. The names of the icons that you remap: %1</source>
        <translation>カスタムアイコンを定義するには exit-options.conf ファイルに IconName=/path/iconame.ext というように記述します。再マッピングするアイコン名: %1</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <source>Other options that can be set in the exit-options.conf file: %1</source>
        <translation>exit-options.conf ファイルで設定可能なその他のオプション: %1</translation>
    </message>
</context>
</TS>
